sunmi_external_cloud_printer library
Classes
- PrintJob
- Builds a buffered sequence of print commands to send in a single SunmiExternalCloudPrinter.commit call.
- SunmiDiscoveredPrinter
- A printer discovered during a scan.
- SunmiExternalCloudPrinter
- High-level Dart API for Sunmi external cloud printers (NT21x / NT31x / NT32x).
- SunmiPrinterStatus
- Current status of a connected printer.
- SunmiPrintResult
- Result of a committed print job.
Enums
- SunmiEncodeType
- Text encoding mode used by the printer firmware for text-mode printing.
- SunmiImageAlgorithm
- Image rasterization algorithm used by the printer firmware.
- SunmiPrintAlignment
- Text alignment choices.
- SunmiQrErrorLevel
- QR code error correction level.