SunmiDiscoveredPrinter class final

A printer discovered during a scan.

Constructors

SunmiDiscoveredPrinter({required String id, required String name, required String connectionType, required String address, required int port, required String mac, required int vid, required int pid})
const

Properties

address String
IP address (LAN only).
final
connectionType String
Connection medium: "USB", "LAN", or "Bluetooth".
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier used to reference this printer in SunmiExternalCloudPrinter.connect.
final
mac String
Bluetooth MAC address (Bluetooth only).
final
name String
Human-readable printer name.
final
pid int
USB product ID (USB only).
final
port int
TCP port (LAN only).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vid int
USB vendor ID (USB only).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited